Contributing to BSPump
===

This document outlines some of the conventions for contributing to BSPump code.

## Coding conventions

BSPump is a Python project.

### Imports

Imports shall be writen one-per-line style as per the example below

```
import os
import sys
import logging
...
```

### Documenting functions, methods and classes

Functions, methods and classes should be documented using quotation marks, see the example below

```
def publish(self, event_name, *args, **kwargs):
	""" Notify subscribers of an event with arguments. """

	callback_set = self.subscribers.get(event_name)
	...
```
